# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import nomad_pilot_cli
from nomad_pilot_cli.models.api_response_connector_response import ApiResponseConnectorResponse  # noqa: E501
from nomad_pilot_cli.rest import ApiException

class TestApiResponseConnectorResponse(unittest.TestCase):
    """ApiResponseConnectorResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ApiResponseConnectorResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = nomad_pilot_cli.models.api_response_connector_response.ApiResponseConnectorResponse()  # noqa: E501
        if include_optional :
            return ApiResponseConnectorResponse(
                input = '{"product_id": 12121}', 
                mapping_name = 'GetProductOp', 
                api = [
                    '0'
                    ], 
                http_request_raw_data = '-', 
                code = 56, 
                response = '0', 
                response_en = '0', 
                platform = 'youzan', 
                request_count = 1, 
                response_time = 1000
            )
        else :
            return ApiResponseConnectorResponse(
        )

    def testApiResponseConnectorResponse(self):
        """Test ApiResponseConnectorResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nomad_pilot_cli.configuration import Configuration


class ApiResponseConnectorResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'input': 'str',
        'mapping_name': 'str',
        'api': 'list[str]',
        'http_request_raw_data': 'str',
        'code': 'int',
        'response': 'str',
        'response_en': 'str',
        'platform': 'str',
        'request_count': 'int',
        'response_time': 'int'
    }

    attribute_map = {
        'input': 'input',
        'mapping_name': 'mappingName',
        'api': 'api',
        'http_request_raw_data': 'httpRequestRawData',
        'code': 'code',
        'response': 'response',
        'response_en': 'responseEn',
        'platform': 'platform',
        'request_count': 'requestCount',
        'response_time': 'responseTime'
    }

    def __init__(self, input=None, mapping_name=None, api=None, http_request_raw_data=None, code=None, response=None, response_en=None, platform=None, request_count=None, response_time=None, local_vars_configuration=None):  # noqa: E501
        """ApiResponseConnectorResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._input = None
        self._mapping_name = None
        self._api = None
        self._http_request_raw_data = None
        self._code = None
        self._response = None
        self._response_en = None
        self._platform = None
        self._request_count = None
        self._response_time = None
        self.discriminator = None

        if input is not None:
            self.input = input
        if mapping_name is not None:
            self.mapping_name = mapping_name
        if api is not None:
            self.api = api
        if http_request_raw_data is not None:
            self.http_request_raw_data = http_request_raw_data
        if code is not None:
            self.code = code
        if response is not None:
            self.response = response
        if response_en is not None:
            self.response_en = response_en
        if platform is not None:
            self.platform = platform
        if request_count is not None:
            self.request_count = request_count
        if response_time is not None:
            self.response_time = response_time

    @property
    def input(self):
        """Gets the input of this ApiResponseConnectorResponse.  # noqa: E501

        The input of a NomadOperation, usually it's JSON format.  # noqa: E501

        :return: The input of this ApiResponseConnectorResponse.  # noqa: E501
        :rtype: str
        """
        return self._input

    @input.setter
    def input(self, input):
        """Sets the input of this ApiResponseConnectorResponse.

        The input of a NomadOperation, usually it's JSON format.  # noqa: E501

        :param input: The input of this ApiResponseConnectorResponse.  # noqa: E501
        :type: str
        """

        self._input = input

    @property
    def mapping_name(self):
        """Gets the mapping_name of this ApiResponseConnectorResponse.  # noqa: E501

        The name of mapping class.  # noqa: E501

        :return: The mapping_name of this ApiResponseConnectorResponse.  # noqa: E501
        :rtype: str
        """
        return self._mapping_name

    @mapping_name.setter
    def mapping_name(self, mapping_name):
        """Sets the mapping_name of this ApiResponseConnectorResponse.

        The name of mapping class.  # noqa: E501

        :param mapping_name: The mapping_name of this ApiResponseConnectorResponse.  # noqa: E501
        :type: str
        """

        self._mapping_name = mapping_name

    @property
    def api(self):
        """Gets the api of this ApiResponseConnectorResponse.  # noqa: E501


        :return: The api of this ApiResponseConnectorResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._api

    @api.setter
    def api(self, api):
        """Sets the api of this ApiResponseConnectorResponse.


        :param api: The api of this ApiResponseConnectorResponse.  # noqa: E501
        :type: list[str]
        """

        self._api = api

    @property
    def http_request_raw_data(self):
        """Gets the http_request_raw_data of this ApiResponseConnectorResponse.  # noqa: E501

        Raw data of current HTTP request to the third party server, easy for debug.  # noqa: E501

        :return: The http_request_raw_data of this ApiResponseConnectorResponse.  # noqa: E501
        :rtype: str
        """
        return self._http_request_raw_data

    @http_request_raw_data.setter
    def http_request_raw_data(self, http_request_raw_data):
        """Sets the http_request_raw_data of this ApiResponseConnectorResponse.

        Raw data of current HTTP request to the third party server, easy for debug.  # noqa: E501

        :param http_request_raw_data: The http_request_raw_data of this ApiResponseConnectorResponse.  # noqa: E501
        :type: str
        """

        self._http_request_raw_data = http_request_raw_data

    @property
    def code(self):
        """Gets the code of this ApiResponseConnectorResponse.  # noqa: E501


        :return: The code of this ApiResponseConnectorResponse.  # noqa: E501
        :rtype: int
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this ApiResponseConnectorResponse.


        :param code: The code of this ApiResponseConnectorResponse.  # noqa: E501
        :type: int
        """

        self._code = code

    @property
    def response(self):
        """Gets the response of this ApiResponseConnectorResponse.  # noqa: E501


        :return: The response of this ApiResponseConnectorResponse.  # noqa: E501
        :rtype: str
        """
        return self._response

    @response.setter
    def response(self, response):
        """Sets the response of this ApiResponseConnectorResponse.


        :param response: The response of this ApiResponseConnectorResponse.  # noqa: E501
        :type: str
        """

        self._response = response

    @property
    def response_en(self):
        """Gets the response_en of this ApiResponseConnectorResponse.  # noqa: E501


        :return: The response_en of this ApiResponseConnectorResponse.  # noqa: E501
        :rtype: str
        """
        return self._response_en

    @response_en.setter
    def response_en(self, response_en):
        """Sets the response_en of this ApiResponseConnectorResponse.


        :param response_en: The response_en of this ApiResponseConnectorResponse.  # noqa: E501
        :type: str
        """

        self._response_en = response_en

    @property
    def platform(self):
        """Gets the platform of this ApiResponseConnectorResponse.  # noqa: E501


        :return: The platform of this ApiResponseConnectorResponse.  # noqa: E501
        :rtype: str
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """Sets the platform of this ApiResponseConnectorResponse.


        :param platform: The platform of this ApiResponseConnectorResponse.  # noqa: E501
        :type: str
        """

        self._platform = platform

    @property
    def request_count(self):
        """Gets the request_count of this ApiResponseConnectorResponse.  # noqa: E501

        The number of requests against the third party in one Nomad request.  # noqa: E501

        :return: The request_count of this ApiResponseConnectorResponse.  # noqa: E501
        :rtype: int
        """
        return self._request_count

    @request_count.setter
    def request_count(self, request_count):
        """Sets the request_count of this ApiResponseConnectorResponse.

        The number of requests against the third party in one Nomad request.  # noqa: E501

        :param request_count: The request_count of this ApiResponseConnectorResponse.  # noqa: E501
        :type: int
        """

        self._request_count = request_count

    @property
    def response_time(self):
        """Gets the response_time of this ApiResponseConnectorResponse.  # noqa: E501

        The response time of current NomadOperation request, including sub-NomadOperation. The time unit is millisecond.  # noqa: E501

        :return: The response_time of this ApiResponseConnectorResponse.  # noqa: E501
        :rtype: int
        """
        return self._response_time

    @response_time.setter
    def response_time(self, response_time):
        """Sets the response_time of this ApiResponseConnectorResponse.

        The response time of current NomadOperation request, including sub-NomadOperation. The time unit is millisecond.  # noqa: E501

        :param response_time: The response_time of this ApiResponseConnectorResponse.  # noqa: E501
        :type: int
        """

        self._response_time = response_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiResponseConnectorResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApiResponseConnectorResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.29.1"

# import apis into sdk package
from nomad_pilot_cli.api.freight_forward_api import FreightForwardApi
from nomad_pilot_cli.api.quick_ship_api import QuickShipApi
from nomad_pilot_cli.api.ship_api import ShipApi
from nomad_pilot_cli.api.ship_confirm_api import ShipConfirmApi

# import ApiClient
from nomad_pilot_cli.api_client import ApiClient
from nomad_pilot_cli.configuration import Configuration
from nomad_pilot_cli.exceptions import OpenApiException
from nomad_pilot_cli.exceptions import ApiTypeError
from nomad_pilot_cli.exceptions import ApiValueError
from nomad_pilot_cli.exceptions import ApiKeyError
from nomad_pilot_cli.exceptions import ApiException
# import models into sdk package
from nomad_pilot_cli.models.address import Address
from nomad_pilot_cli.models.address_required import AddressRequired
from nomad_pilot_cli.models.address_ship import AddressShip
from nomad_pilot_cli.models.api_response import ApiResponse
from nomad_pilot_cli.models.api_response_connector_response import ApiResponseConnectorResponse
from nomad_pilot_cli.models.api_response_data import ApiResponseData
from nomad_pilot_cli.models.api_response_general import ApiResponseGeneral
from nomad_pilot_cli.models.dimension import Dimension
from nomad_pilot_cli.models.goldjet import Goldjet
from nomad_pilot_cli.models.pack import Pack
from nomad_pilot_cli.models.pack_based import PackBased
from nomad_pilot_cli.models.package import Package
from nomad_pilot_cli.models.package_item import PackageItem
from nomad_pilot_cli.models.package_item_quick import PackageItemQuick
from nomad_pilot_cli.models.package_items import PackageItems
from nomad_pilot_cli.models.package_items_quick import PackageItemsQuick
from nomad_pilot_cli.models.package_quick import PackageQuick
from nomad_pilot_cli.models.package_required import PackageRequired
from nomad_pilot_cli.models.package_update import PackageUpdate
from nomad_pilot_cli.models.package_update_required import PackageUpdateRequired




import base64
import datetime
import hashlib
import hmac
import json
import logging
import os
import sys
import uuid
from copy import deepcopy

from urllib3.util import parse_url
from urllib3.util.url import Url

log = logging.getLogger(__name__)
log.setLevel(logging.INFO)
log.propagate = False
out_handler = logging.StreamHandler(sys.stdout)
out_handler.setLevel(logging.INFO)
log.addHandler(out_handler)

logger = logging.getLogger(__name__)

__all__ = ['append_alibaba_headers',
           'keep_configuration_in_RESTClientObject',
           'AppendAlibabaHeaders']

"""
Append Alibaba authentication headers based on original full HTTP request.

This Python implementation is modified from
https://github.com/aliyun/api-gateway-nodejs-sdk

---------------------------

Example Swagger Client usage:

class TestAlicloudApigateway(unittest.TestCase):
    store = 'samarkand.youzan.foreveryoung'

    @classmethod
    def setUpClass(cls):
        configuration = nomad_envoy_cli.Configuration()
        configuration.host = os.environ["ALICLOUD_APIGATEWAY_HOST"] + "/envoy"
        configuration.api_key = {
            "x-ca-key": os.environ["ALICLOUD_APIGATEWAY_APP_KEY"],
            "x-ca-stage": os.environ["ALICLOUD_STAGE"],
        }
        configuration.alibaba = {"ALICLOUD_APIGATEWAY_APP_SECRET": os.environ[
            "ALICLOUD_APIGATEWAY_APP_SECRET"]}

        cls.order_api = OrderApi(ApiClient(configuration))
        cls.product_api = ProductApi(ApiClient(configuration))

    def test_order(self):
        result = self.order_api.get_order_by_field(
            self.store, _request_timeout=60 * 1000)

        self.assertEqual(result.code, 200)
        self.assertTrue(len(result.data.orders) > 0,
                        "we at least have one order.")
"""


def append_alibaba_headers(func):
    """
    A Python decorator to modify the request made by Swagger Client.

    The original method is RESTClientObject.request:

        def request(self, method, url, query_params=None, headers=None,
                body=None, post_params=None, _preload_content=True,
                _request_timeout=None):
            pass
    """

    def wrapper(*args, **kw):
        # 1. Re-organize parameters
        self = args[0]
        method = args[1]
        url = args[2]
        query_params = kw.get('query_params', {})
        headers = kw.get('headers', {})
        body = kw.get('body', {}) or {}

        # Since our API is slow, then let our client be ready to wait.
        kw["_request_timeout"] = 60 * 30  # 30 seconds

        # 2. Translating original Node.js code into below Python code.
        aah = AppendAlibabaHeaders(self.configuration, method, url,
                                   query_params, headers, body)
        headers = aah.result()

        # 3 .Write things back to args and kw if we changed anything.
        kw["headers"] = headers

        if os.environ.get("NOMAD_DEBUG", None) == "TRUE":
            log.info("""  --------- debug Alibaba Client request ---------
method: %s
url: %s
query_params: %s
headers: %s
body: %s

            """ % (
                method,
                url,
                json_dumps_unicode(query_params),
                json_dumps_unicode(headers),
                json_dumps_unicode(body)
            ))

        return func(*args, **kw)

    return wrapper


def keep_configuration_in_RESTClientObject(func):
    """
    We need to access "configuration" inside of @append_alibaba_headers.
    """

    def wrapper(*args, **kw):
        self = args[0]
        configuration = args[1]
        self.configuration = configuration
        func(*args, **kw)

    return wrapper


class AppendAlibabaHeaders(object):
    sign_headers = {}
    content_type_form = 'application/x-www-form-urlencoded'

    def __init__(self,
                 configuration,  # SwaggerClient.Configuration
                 method: str,
                 url: str,
                 query_params: dict,
                 headers: dict,
                 body: dict):
        self.configuration = configuration
        self.method = method
        self.url = url
        self.query_params = query_params
        if isinstance(self.query_params, list):
            self.query_params = {i[0]: i[1] for i in self.query_params}
        self.body = body

        self.original_data_dict = {}
        self.original_data_dict.update(self.query_params)
        if isinstance(self.body, dict):
            self.original_data_dict.update(self.body)

        self.x_ca_timestamp = int(datetime.datetime.now().timestamp() * 1000)
        # TODO client would reuse the request, maybe should re-generate nonce.
        self.x_ca_nonce = str(uuid.uuid4())
        self.headers = {k.lower(): headers[k] for k in headers.keys()}
        self.content = None

    def initial_headers(self, headers):
        d = {
            'x-ca-timestamp': self.x_ca_timestamp,
            'x-ca-key': self.configuration.api_key.get("x-ca-key", ""),
            'x-ca-nonce': self.x_ca_nonce,
            'x-ca-stage': self.configuration.api_key.get("x-ca-stage", "test"),
            'accept': 'application/json',
        }
        d.update(headers)
        d.update({"content-type": self.request_content_type})
        d.update(self.sign_headers)
        return d

    def get_sign_header_keys(self, headers: dict, sign_headers: dict) -> list:
        sign_keys = [h for h in headers
                     if h.startswith("x-ca-") or h in sign_headers]
        return list(sorted(sign_keys))

    def get_signed_headers_string(self, sign_headers: list, headers: dict) -> \
            str:
        return "\n".join([h + ":" + str(headers[h]) for h in sign_headers])

    def build_string_to_sign(self,
                             method,
                             headers,
                             signed_headers_str,
                             url: Url,
                             data) -> str:
        lf = "\n"

        content_type = headers.get('content-type', '')

        buffer = [
            method,
            headers.get('accept', ""),
            headers.get('content-md5', ""),
            content_type,
            headers.get('date', None),
        ]

        if signed_headers_str:
            buffer.append(signed_headers_str)

        buffer.append(self.build_url(url, content_type, data))

        return lf.join([v or "" for v in buffer])

    def build_url(self, url: Url, content_type, data=None) -> str:
        new_query = deepcopy(self.query_params or {})
        if content_type.startswith(self.content_type_form):
            new_query.update(data or {})

        query_list = []
        for k in sorted(new_query.keys()):
            if new_query[k] is not None:
                query_list.append(k + "=" + str(new_query[k]))
            else:
                query_list.append(k)
        query_str = "&".join(query_list)
        return url.path + "?" + query_str if query_str else url.path

    def sign(self, string_to_sign) -> str:
        assert hasattr(self.configuration, "platform_parameters"), \
            "Please assgin a dictionary called \"platform_parameters\" to " + \
            "self.configuration before use this Alibaba Swagger Client."

        secret = self.configuration.platform_parameters[
            "ALICLOUD_APIGATEWAY_APP_SECRET"].encode("utf-8")
        m = hmac.new(secret, digestmod=hashlib.sha256)
        m.update(string_to_sign.encode('utf-8'))
        return base64.b64encode(m.digest()).decode('utf-8')

    @property
    def request_content_type(self):
        # note: Samarkand use JSON as the default format.
        return self.headers.get("content-type", "application/json")

    @property
    def is_content_type_form(self):
        return self.request_content_type.startswith(self.content_type_form)

    def result(self) -> dict:
        auth_headers = self.initial_headers(self.headers)

        if (self.method.upper() == "POST") and (not self.is_content_type_form):
            # querystring.stringify_obj(self.original_data_dict)
            # TODO could we avoid another duplicate json.dumps in rest#request
            # this md5 works, verified by changing this string a bit.
            self.content = json.dumps(self.body)
            auth_headers["content-md5"] = md5(self.content)

        sign_header_keys = self.get_sign_header_keys(auth_headers,
                                                     self.sign_headers)
        auth_headers['x-ca-signature-headers'] = ','.join(sign_header_keys)
        signed_headers_str = self.get_signed_headers_string(sign_header_keys,
                                                            auth_headers)

        self.stringToSign = self.build_string_to_sign(self.method,
                                                      auth_headers,
                                                      signed_headers_str,
                                                      parse_url(self.url),
                                                      self.body)

        auth_headers['x-ca-signature'] = self.sign(self.stringToSign)

        return auth_headers


def md5(content: str) -> str:
    m = hashlib.md5()
    m.update(content.encode('utf-8'))
    return base64.b64encode(m.digest()).decode("utf-8")


def json_dumps_unicode(obj):
    """
    Change Python default json.dumps acting like JavaScript, including allow
    Chinese characters and no space between any keys or values.
    """
    return json.dumps(obj,
                      ensure_ascii=False,
                      separators=(',', ':')
                      )



# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import nomad_pilot_cli
from nomad_pilot_cli.models.pack_based import PackBased  # noqa: E501
from nomad_pilot_cli.rest import ApiException

class TestPackBased(unittest.TestCase):
    """PackBased unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PackBased
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = nomad_pilot_cli.models.pack_based.PackBased()  # noqa: E501
        if include_optional :
            return PackBased(
                dimension = nomad_pilot_cli.models.dimension.Dimension(
                    weight = 1.337, 
                    height = 1.337, 
                    length = 1.337, 
                    width = 1.337, ), 
                ship_from = nomad_pilot_cli.models.address.Address(
                    first_name = 'John', 
                    last_name = '0', 
                    address1 = '0', 
                    address2 = '0', 
                    county = '0', 
                    city = '0', 
                    state = '0', 
                    country = '0', 
                    zip = '0', 
                    tin = '0', 
                    phone = '0', 
                    country_code = '142', 
                    id_card = '0', 
                    email = '0', 
                    company = '0', 
                    ecommerce_website_user_id = '0', ), 
                ship_to = nomad_pilot_cli.models.address.Address(
                    first_name = 'John', 
                    last_name = '0', 
                    address1 = '0', 
                    address2 = '0', 
                    county = '0', 
                    city = '0', 
                    state = '0', 
                    country = '0', 
                    zip = '0', 
                    tin = '0', 
                    phone = '0', 
                    country_code = '142', 
                    id_card = '0', 
                    email = '0', 
                    company = '0', 
                    ecommerce_website_user_id = '0', ), 
                bill = nomad_pilot_cli.models.address.Address(
                    first_name = 'John', 
                    last_name = '0', 
                    address1 = '0', 
                    address2 = '0', 
                    county = '0', 
                    city = '0', 
                    state = '0', 
                    country = '0', 
                    zip = '0', 
                    tin = '0', 
                    phone = '0', 
                    country_code = '142', 
                    id_card = '0', 
                    email = '0', 
                    company = '0', 
                    ecommerce_website_user_id = '0', ), 
                order_ref = '0', 
                seller_order_ref = '0', 
                tracking_reference = '0', 
                order_time = '0', 
                gross_weight = 1.337, 
                net_weight = 1.337, 
                total_price = 1.337, 
                currency = 'RMB', 
                mass_unit = 'Kilogram', 
                length_unit = 'Centimetre', 
                domestic_delivery_company = 'YTO', 
                created_at = '2019-07-12T13:13:52.004637+01:00', 
                updated_at = '2019-07-12T13:13:52.004637+01:00', 
                pay_method = 'EASIPAY', 
                pay_merchant_name = 'Paypal', 
                pay_amount = 611.08, 
                pay_id = '2014030120394812', 
                paid_at = '2019-07-12T13:13:52.004637+01:00', 
                products_total_tax = 53.28, 
                shipping_cost = 25.0, 
                non_cash_deduction_amount = 0.0, 
                customer_note = 'This package is very important.', 
                cancel_reason = 'The customers updated the address.', 
                warehouse_code = '718595286704', 
                customer_id_ref = '0', 
                insurance_fee = 2.5, 
                express_type = 'BC', 
                payment_pay_id = '191028195204000214', 
                platform_name = 'youzan', 
                check_point = '0'
            )
        else :
            return PackBased(
        )

    def testPackBased(self):
        """Test PackBased"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import nomad_pilot_cli
from nomad_pilot_cli.api.ship_confirm_api import ShipConfirmApi  # noqa: E501
from nomad_pilot_cli.rest import ApiException


class TestShipConfirmApi(unittest.TestCase):
    """ShipConfirmApi unit test stubs"""

    def setUp(self):
        self.api = nomad_pilot_cli.api.ship_confirm_api.ShipConfirmApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_ship_confirm(self):
        """Test case for ship_confirm

        shipConfirm  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from nomad_pilot_cli.api.freight_forward_api import FreightForwardApi
from nomad_pilot_cli.api.quick_ship_api import QuickShipApi
from nomad_pilot_cli.api.ship_api import ShipApi
from nomad_pilot_cli.api.ship_confirm_api import ShipConfirmApi



# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import nomad_pilot_cli
from nomad_pilot_cli.models.api_response import ApiResponse  # noqa: E501
from nomad_pilot_cli.rest import ApiException

class TestApiResponse(unittest.TestCase):
    """ApiResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ApiResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = nomad_pilot_cli.models.api_response.ApiResponse()  # noqa: E501
        if include_optional :
            return ApiResponse(
                code = 56, 
                message = '0', 
                data = nomad_pilot_cli.models.api_response_data.ApiResponseData(
                    waybill_id = '0', 
                    order_sn = '0', 
                    order_ref = '0', 
                    seller_order_ref = '0', 
                    domestic_delivery_company = 'YTO', 
                    delivery_status = '0', 
                    delivery_note = '0', 
                    delivery_slip_url = '0', 
                    tracking_url = '0', 
                    check_points = ["@accept_time 2020-05-01 04:59:38; @accept_address 伦敦; @remark 寄方准备快件中,当前地点: 【GB London Delivery Centre (英國倫敦收派中心)】; @opcode 647; @zoneGmt 1","...","@accept_time 2020-05-13 09:10:49; @accept_address 江门市;  @remark 在官网'运单资料&签收图',可查看签收人信息; @opcode 8000; @stayWhyCode  1; @zoneGmt 8"], ), 
                connector_responses = [
                    nomad_pilot_cli.models.api_response_connector_response.ApiResponseConnectorResponse(
                        input = '{"product_id": 12121}', 
                        mapping_name = 'GetProductOp', 
                        api = [
                            '0'
                            ], 
                        http_request_raw_data = '-', 
                        code = 56, 
                        response = '0', 
                        response_en = '0', 
                        platform = 'youzan', 
                        request_count = 1, 
                        response_time = 1000, )
                    ], 
                response_time = 1000
            )
        else :
            return ApiResponse(
        )

    def testApiResponse(self):
        """Test ApiResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import nomad_pilot_cli
from nomad_pilot_cli.models.package_required import PackageRequired  # noqa: E501
from nomad_pilot_cli.rest import ApiException

class TestPackageRequired(unittest.TestCase):
    """PackageRequired unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PackageRequired
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = nomad_pilot_cli.models.package_required.PackageRequired()  # noqa: E501
        if include_optional :
            return PackageRequired(
                seller_order_ref = '0', 
                express_type = '0', 
                currency = 'RMB', 
                mass_unit = 'Kilogram', 
                length_unit = 'Centimetre', 
                ship_from = null, 
                ship_to = null
            )
        else :
            return PackageRequired(
                seller_order_ref = '0',
                express_type = '0',
                currency = 'RMB',
                mass_unit = 'Kilogram',
                length_unit = 'Centimetre',
        )

    def testPackageRequired(self):
        """Test PackageRequired"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nomad_pilot_cli.configuration import Configuration


class AddressShip(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'first_name': 'str',
        'last_name': 'str',
        'address1': 'str',
        'address2': 'str',
        'county': 'str',
        'city': 'str',
        'state': 'str',
        'country': 'str',
        'zip': 'str',
        'tin': 'str',
        'phone': 'str',
        'country_code': 'str',
        'id_card': 'str',
        'email': 'str',
        'company': 'str',
        'ecommerce_website_user_id': 'str'
    }

    attribute_map = {
        'first_name': 'firstName',
        'last_name': 'lastName',
        'address1': 'address1',
        'address2': 'address2',
        'county': 'county',
        'city': 'city',
        'state': 'state',
        'country': 'country',
        'zip': 'zip',
        'tin': 'tin',
        'phone': 'phone',
        'country_code': 'countryCode',
        'id_card': 'idCard',
        'email': 'email',
        'company': 'company',
        'ecommerce_website_user_id': 'ecommerceWebsiteUserId'
    }

    def __init__(self, first_name=None, last_name=None, address1=None, address2=None, county=None, city=None, state=None, country=None, zip=None, tin=None, phone=None, country_code=None, id_card=None, email=None, company=None, ecommerce_website_user_id=None, local_vars_configuration=None):  # noqa: E501
        """AddressShip - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._first_name = None
        self._last_name = None
        self._address1 = None
        self._address2 = None
        self._county = None
        self._city = None
        self._state = None
        self._country = None
        self._zip = None
        self._tin = None
        self._phone = None
        self._country_code = None
        self._id_card = None
        self._email = None
        self._company = None
        self._ecommerce_website_user_id = None
        self.discriminator = None

        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if address1 is not None:
            self.address1 = address1
        if address2 is not None:
            self.address2 = address2
        if county is not None:
            self.county = county
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        self.country = country
        self.zip = zip
        if tin is not None:
            self.tin = tin
        self.phone = phone
        if country_code is not None:
            self.country_code = country_code
        if id_card is not None:
            self.id_card = id_card
        if email is not None:
            self.email = email
        if company is not None:
            self.company = company
        if ecommerce_website_user_id is not None:
            self.ecommerce_website_user_id = ecommerce_website_user_id

    @property
    def first_name(self):
        """Gets the first_name of this AddressShip.  # noqa: E501


        :return: The first_name of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this AddressShip.


        :param first_name: The first_name of this AddressShip.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this AddressShip.  # noqa: E501


        :return: The last_name of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this AddressShip.


        :param last_name: The last_name of this AddressShip.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def address1(self):
        """Gets the address1 of this AddressShip.  # noqa: E501


        :return: The address1 of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._address1

    @address1.setter
    def address1(self, address1):
        """Sets the address1 of this AddressShip.


        :param address1: The address1 of this AddressShip.  # noqa: E501
        :type: str
        """

        self._address1 = address1

    @property
    def address2(self):
        """Gets the address2 of this AddressShip.  # noqa: E501


        :return: The address2 of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._address2

    @address2.setter
    def address2(self, address2):
        """Sets the address2 of this AddressShip.


        :param address2: The address2 of this AddressShip.  # noqa: E501
        :type: str
        """

        self._address2 = address2

    @property
    def county(self):
        """Gets the county of this AddressShip.  # noqa: E501

        The county of current city. 县/区, e.g. 西湖区  # noqa: E501

        :return: The county of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._county

    @county.setter
    def county(self, county):
        """Sets the county of this AddressShip.

        The county of current city. 县/区, e.g. 西湖区  # noqa: E501

        :param county: The county of this AddressShip.  # noqa: E501
        :type: str
        """

        self._county = county

    @property
    def city(self):
        """Gets the city of this AddressShip.  # noqa: E501


        :return: The city of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this AddressShip.


        :param city: The city of this AddressShip.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this AddressShip.  # noqa: E501


        :return: The state of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this AddressShip.


        :param state: The state of this AddressShip.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this AddressShip.  # noqa: E501


        :return: The country of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this AddressShip.


        :param country: The country of this AddressShip.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and country is None:  # noqa: E501
            raise ValueError("Invalid value for `country`, must not be `None`")  # noqa: E501

        self._country = country

    @property
    def zip(self):
        """Gets the zip of this AddressShip.  # noqa: E501


        :return: The zip of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._zip

    @zip.setter
    def zip(self, zip):
        """Sets the zip of this AddressShip.


        :param zip: The zip of this AddressShip.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and zip is None:  # noqa: E501
            raise ValueError("Invalid value for `zip`, must not be `None`")  # noqa: E501

        self._zip = zip

    @property
    def tin(self):
        """Gets the tin of this AddressShip.  # noqa: E501

        TIN; The Chinese ID number of current person.  # noqa: E501

        :return: The tin of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._tin

    @tin.setter
    def tin(self, tin):
        """Sets the tin of this AddressShip.

        TIN; The Chinese ID number of current person.  # noqa: E501

        :param tin: The tin of this AddressShip.  # noqa: E501
        :type: str
        """

        self._tin = tin

    @property
    def phone(self):
        """Gets the phone of this AddressShip.  # noqa: E501


        :return: The phone of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this AddressShip.


        :param phone: The phone of this AddressShip.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone is None:  # noqa: E501
            raise ValueError("Invalid value for `phone`, must not be `None`")  # noqa: E501

        self._phone = phone

    @property
    def country_code(self):
        """Gets the country_code of this AddressShip.  # noqa: E501

        The customs code of country.  # noqa: E501

        :return: The country_code of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this AddressShip.

        The customs code of country.  # noqa: E501

        :param country_code: The country_code of this AddressShip.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def id_card(self):
        """Gets the id_card of this AddressShip.  # noqa: E501

        The Chinese ID number of current person (will be removed since we are using tin).  # noqa: E501

        :return: The id_card of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._id_card

    @id_card.setter
    def id_card(self, id_card):
        """Sets the id_card of this AddressShip.

        The Chinese ID number of current person (will be removed since we are using tin).  # noqa: E501

        :param id_card: The id_card of this AddressShip.  # noqa: E501
        :type: str
        """

        self._id_card = id_card

    @property
    def email(self):
        """Gets the email of this AddressShip.  # noqa: E501


        :return: The email of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this AddressShip.


        :param email: The email of this AddressShip.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def company(self):
        """Gets the company of this AddressShip.  # noqa: E501


        :return: The company of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this AddressShip.


        :param company: The company of this AddressShip.  # noqa: E501
        :type: str
        """

        self._company = company

    @property
    def ecommerce_website_user_id(self):
        """Gets the ecommerce_website_user_id of this AddressShip.  # noqa: E501

        The user ID of that e-commerce website.  # noqa: E501

        :return: The ecommerce_website_user_id of this AddressShip.  # noqa: E501
        :rtype: str
        """
        return self._ecommerce_website_user_id

    @ecommerce_website_user_id.setter
    def ecommerce_website_user_id(self, ecommerce_website_user_id):
        """Sets the ecommerce_website_user_id of this AddressShip.

        The user ID of that e-commerce website.  # noqa: E501

        :param ecommerce_website_user_id: The ecommerce_website_user_id of this AddressShip.  # noqa: E501
        :type: str
        """

        self._ecommerce_website_user_id = ecommerce_website_user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddressShip):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddressShip):
            return True

        return self.to_dict() != other.to_dict()



import importlib
import json
from datetime import date, datetime
from typing import List, AnyStr, Any, Type, Dict


class SwaggerValidator(object):
    """
    Validate all attributes of a single Swagger model instance. Will raise an
    exception if an invalid type is detected, e.g. an address should be a
    string or None, but False is definitely a wrong type.
    """

    KEY_OPENAPI_TYPES = "openapi_types"
    VALID_NULL = None
    MAPPING_STR_TO_REAL_TYPES: Dict[str, Type] = {
        # Primitive types.
        "str": str,
        "int": int,
        "float": float,
        "bool": bool,

        # Others
        "list": List,
        "dict": Dict,  # TODO need check
        "date": date,  # TODO need check
        "datetime": datetime,  # TODO need check
    }

    # e.g. we have server and client for the same swagger file.
    LOADED_SWAGGER_MODULES = set()

    def __init__(self, obj: Any, _type: Type[object]):
        self.obj: Any = obj
        self._type = _type
        self.errs: List[AnyStr] = []

    @classmethod
    def validate(cls, obj: Any, _type: Type[object]):
        cls._load_str_types_mapping(_type)

        validator = SwaggerValidator(obj, _type)
        validator._validate_obj()
        if validator.errs:
            msg = json_dumps_unicode(validator.errs)
            raise InvalidSwaggerDataType(msg)
        return validator

    def _validate_obj(self):
        # The root object should be a Swagger model instance.
        if not self._is_swagger_model_instance(self._type):
            return self.errs.append(
                "type:%s is not a valid Swagger model due to lacking"
                " attribute:%s" % (self._type, self.KEY_OPENAPI_TYPES))

        # Validate the whole object.
        self._validate_recursively(self.obj, self._type)

    def _validate_recursively(self, obj: Any,
                              _type: Type[object],
                              attr_path: str = None):
        # 1. [root] None is valid.
        if obj is self.VALID_NULL:
            return
        attr_path = attr_path or _type.__name__
        if self._is_same_class_name(obj, _type):
            return self._msg_of_wrong_type(attr_path, obj, _type)

        # 2. [children]
        # instance always can access the attributes of its class.
        field_types_container = obj
        types = getattr(field_types_container, self.KEY_OPENAPI_TYPES, None)
        if types is None:
            return  # 2.0. return earlier if it's general.
        for field_name, field_type in types.items():
            sub_attr_path = attr_path + "." + field_name

            if isinstance(field_type, str):
                # 'eval' is running on the client side, so there's no harm
                # for the server side.
                field_type = eval(field_type, self.MAPPING_STR_TO_REAL_TYPES)

            field_value = getattr(obj, field_name)
            # 2.1. An attribute is valid even it's None.
            if field_value is self.VALID_NULL:
                continue
            # 2.2. Or should be the type as it declared.
            if isinstance(field_type, GenericMeta):
                extra_type = getattr(field_type, "__extra__")
                field_type_args = getattr(field_type, "__args__")
                if extra_type == list:
                    for idx, _item in enumerate(field_value):
                        self._validate_recursively(
                            _item,
                            field_type_args[0],
                            sub_attr_path + "[%s]" % idx
                        )
                if extra_type == dict:  # TODO need check
                    for k, _item in field_value.items():
                        self._validate_recursively(
                            _item,
                            field_type_args[1],
                            sub_attr_path + "." + k
                        )
                continue

            if self._is_same_class_name(field_value, field_type):
                self._msg_of_wrong_type(sub_attr_path, field_value, field_type)
                continue
            # 2.3. Continue to validate if current attribute is still a
            #      composite.
            if self._is_swagger_model_instance(field_value):
                self._validate_recursively(
                    field_value, field_type, sub_attr_path)

    def _msg_of_wrong_type(self, attr_path, obj: Any, _type: Type[object]):
        return self.errs.append(
            "%s=%s does not belong to expected type:%s, but get type:%s" % (
                attr_path, repr(obj), _type, type(obj)))

    def _is_swagger_model_instance(self, obj: Any):
        return hasattr(obj, self.KEY_OPENAPI_TYPES)

    def _is_same_class_name(self, obj: Any, _type: Type[Any]) -> bool:
        """ allow same class names in different packages. """
        return type(obj).__name__ != _type.__name__

    @classmethod
    def _load_str_types_mapping(cls, any_swagger_model) -> Dict[str, Type]:
        # Extracted models module, e.g. from 'swagger_client.models.address'
        models_module_path = ".".join(
            any_swagger_model.__module__.split(".")[:2])
        if models_module_path in cls.LOADED_SWAGGER_MODULES:
            return cls.MAPPING_STR_TO_REAL_TYPES  # already loaded
        models_module = importlib.import_module(models_module_path)

        # 1. Find all Swagger models.
        for field in dir(models_module):
            potential_class = getattr(models_module, field)
            if hasattr(potential_class, cls.KEY_OPENAPI_TYPES):
                cls.MAPPING_STR_TO_REAL_TYPES[field] = \
                    potential_class

        cls.LOADED_SWAGGER_MODULES.add(models_module_path)
        return cls.MAPPING_STR_TO_REAL_TYPES


def json_dumps_unicode(obj):
    """
    Change Python default json.dumps acting like JavaScript, including allow
    Chinese characters and no space between any keys or values.
    """
    return json.dumps(obj,
                      ensure_ascii=False,
                      separators=(',', ':')
                      )


class InvalidSwaggerDataType(Exception):
    pass

try:
    from typing import GenericMeta  # python < 3.7
except ImportError:
    # in 3.7, genericmeta doesn't exist but we don't need it
    class GenericMeta(type): pass



# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from nomad_pilot_cli.api_client import ApiClient
from nomad_pilot_cli.exceptions import (
    ApiTypeError,
    ApiValueError
)


class FreightForwardApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def query_freight_forward(self, carrier, status, page_no, page_size, **kwargs):  # noqa: E501
        """queryFreightForward  # noqa: E501

        Query a specfic waybill in Freight Forwarding.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_freight_forward(carrier, status, page_no, page_size, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str carrier: Carrier to ship with (required)
        :param str status: package status, 2 available options: [CREATED, PROCESSED] (required)
        :param int page_no: Page number, between 1 and 1000 (required)
        :param int page_size: Page size, options: [1, 10, 50, 100] (required)
        :param list[str] tracking_refs: String name of tracking reference by Express Company. One or more tracking references: [SF1026045099931, SF1025950147480]
        :param str created_range: the time range of package update, use ISO_8601 format here, e.g. 2020-07-10T13:00:00Z/2020-07-11T15:30:00Z
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ApiResponseGeneral
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.query_freight_forward_with_http_info(carrier, status, page_no, page_size, **kwargs)  # noqa: E501

    def query_freight_forward_with_http_info(self, carrier, status, page_no, page_size, **kwargs):  # noqa: E501
        """queryFreightForward  # noqa: E501

        Query a specfic waybill in Freight Forwarding.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_freight_forward_with_http_info(carrier, status, page_no, page_size, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str carrier: Carrier to ship with (required)
        :param str status: package status, 2 available options: [CREATED, PROCESSED] (required)
        :param int page_no: Page number, between 1 and 1000 (required)
        :param int page_size: Page size, options: [1, 10, 50, 100] (required)
        :param list[str] tracking_refs: String name of tracking reference by Express Company. One or more tracking references: [SF1026045099931, SF1025950147480]
        :param str created_range: the time range of package update, use ISO_8601 format here, e.g. 2020-07-10T13:00:00Z/2020-07-11T15:30:00Z
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ApiResponseGeneral, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['carrier', 'status', 'page_no', 'page_size', 'tracking_refs', 'created_range']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_freight_forward" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'carrier' is set
        if self.api_client.client_side_validation and ('carrier' not in local_var_params or  # noqa: E501
                                                        local_var_params['carrier'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `carrier` when calling `query_freight_forward`")  # noqa: E501
        # verify the required parameter 'status' is set
        if self.api_client.client_side_validation and ('status' not in local_var_params or  # noqa: E501
                                                        local_var_params['status'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `status` when calling `query_freight_forward`")  # noqa: E501
        # verify the required parameter 'page_no' is set
        if self.api_client.client_side_validation and ('page_no' not in local_var_params or  # noqa: E501
                                                        local_var_params['page_no'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `page_no` when calling `query_freight_forward`")  # noqa: E501
        # verify the required parameter 'page_size' is set
        if self.api_client.client_side_validation and ('page_size' not in local_var_params or  # noqa: E501
                                                        local_var_params['page_size'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `page_size` when calling `query_freight_forward`")  # noqa: E501

        if self.api_client.client_side_validation and 'page_no' in local_var_params and local_var_params['page_no'] > 1000:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `page_no` when calling `query_freight_forward`, must be a value less than or equal to `1000`")  # noqa: E501
        if self.api_client.client_side_validation and 'page_no' in local_var_params and local_var_params['page_no'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `page_no` when calling `query_freight_forward`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('tracking_refs' in local_var_params and  # noqa: E501
                                                        len(local_var_params['tracking_refs']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `tracking_refs` when calling `query_freight_forward`, number of items must be less than or equal to `100`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'carrier' in local_var_params:
            path_params['carrier'] = local_var_params['carrier']  # noqa: E501

        query_params = []
        if 'status' in local_var_params and local_var_params['status'] is not None:  # noqa: E501
            query_params.append(('status', local_var_params['status']))  # noqa: E501
        if 'page_no' in local_var_params and local_var_params['page_no'] is not None:  # noqa: E501
            query_params.append(('page_no', local_var_params['page_no']))  # noqa: E501
        if 'page_size' in local_var_params and local_var_params['page_size'] is not None:  # noqa: E501
            query_params.append(('page_size', local_var_params['page_size']))  # noqa: E501
        if 'tracking_refs' in local_var_params and local_var_params['tracking_refs'] is not None:  # noqa: E501
            query_params.append(('tracking_refs', local_var_params['tracking_refs']))  # noqa: E501
            collection_formats['tracking_refs'] = 'csv'  # noqa: E501
        if 'created_range' in local_var_params and local_var_params['created_range'] is not None:  # noqa: E501
            query_params.append(('created_range', local_var_params['created_range']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ca_key']  # noqa: E501

        return self.api_client.call_api(
            '/freight-forward/{carrier}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseGeneral',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nomad_pilot_cli.configuration import Configuration


class Dimension(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'weight': 'float',
        'height': 'float',
        'length': 'float',
        'width': 'float'
    }

    attribute_map = {
        'weight': 'weight',
        'height': 'height',
        'length': 'length',
        'width': 'width'
    }

    def __init__(self, weight=None, height=None, length=None, width=None, local_vars_configuration=None):  # noqa: E501
        """Dimension - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._weight = None
        self._height = None
        self._length = None
        self._width = None
        self.discriminator = None

        if weight is not None:
            self.weight = weight
        if height is not None:
            self.height = height
        if length is not None:
            self.length = length
        if width is not None:
            self.width = width

    @property
    def weight(self):
        """Gets the weight of this Dimension.  # noqa: E501

        The whole package, not just the products. kilogram.  # noqa: E501

        :return: The weight of this Dimension.  # noqa: E501
        :rtype: float
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this Dimension.

        The whole package, not just the products. kilogram.  # noqa: E501

        :param weight: The weight of this Dimension.  # noqa: E501
        :type: float
        """

        self._weight = weight

    @property
    def height(self):
        """Gets the height of this Dimension.  # noqa: E501

        the height of current package. centimetre.  # noqa: E501

        :return: The height of this Dimension.  # noqa: E501
        :rtype: float
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this Dimension.

        the height of current package. centimetre.  # noqa: E501

        :param height: The height of this Dimension.  # noqa: E501
        :type: float
        """

        self._height = height

    @property
    def length(self):
        """Gets the length of this Dimension.  # noqa: E501

        the length of current package. centimetre.  # noqa: E501

        :return: The length of this Dimension.  # noqa: E501
        :rtype: float
        """
        return self._length

    @length.setter
    def length(self, length):
        """Sets the length of this Dimension.

        the length of current package. centimetre.  # noqa: E501

        :param length: The length of this Dimension.  # noqa: E501
        :type: float
        """

        self._length = length

    @property
    def width(self):
        """Gets the width of this Dimension.  # noqa: E501

        the width of current package. centimetre.  # noqa: E501

        :return: The width of this Dimension.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this Dimension.

        the width of current package. centimetre.  # noqa: E501

        :param width: The width of this Dimension.  # noqa: E501
        :type: float
        """

        self._width = width

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Dimension):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Dimension):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nomad_pilot_cli.configuration import Configuration


class PackageUpdate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'dimension': 'Dimension',
        'ship_from': 'Address',
        'ship_to': 'Address',
        'bill': 'Address',
        'order_ref': 'str',
        'seller_order_ref': 'str',
        'tracking_reference': 'str',
        'order_time': 'str',
        'gross_weight': 'float',
        'net_weight': 'float',
        'total_price': 'float',
        'currency': 'str',
        'mass_unit': 'str',
        'length_unit': 'str',
        'domestic_delivery_company': 'str',
        'created_at': 'str',
        'updated_at': 'str',
        'pay_method': 'str',
        'pay_merchant_name': 'str',
        'pay_amount': 'float',
        'pay_id': 'str',
        'paid_at': 'str',
        'products_total_tax': 'float',
        'shipping_cost': 'float',
        'non_cash_deduction_amount': 'float',
        'customer_note': 'str',
        'cancel_reason': 'str',
        'warehouse_code': 'str',
        'customer_id_ref': 'str',
        'insurance_fee': 'float',
        'express_type': 'str',
        'payment_pay_id': 'str',
        'platform_name': 'str',
        'check_point': 'str',
        'items': 'list[PackageItem]'
    }

    attribute_map = {
        'dimension': 'dimension',
        'ship_from': 'shipFrom',
        'ship_to': 'shipTo',
        'bill': 'bill',
        'order_ref': 'orderRef',
        'seller_order_ref': 'sellerOrderRef',
        'tracking_reference': 'trackingReference',
        'order_time': 'orderTime',
        'gross_weight': 'grossWeight',
        'net_weight': 'netWeight',
        'total_price': 'totalPrice',
        'currency': 'currency',
        'mass_unit': 'massUnit',
        'length_unit': 'lengthUnit',
        'domestic_delivery_company': 'domesticDeliveryCompany',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'pay_method': 'payMethod',
        'pay_merchant_name': 'payMerchantName',
        'pay_amount': 'payAmount',
        'pay_id': 'payId',
        'paid_at': 'paidAt',
        'products_total_tax': 'productsTotalTax',
        'shipping_cost': 'shippingCost',
        'non_cash_deduction_amount': 'nonCashDeductionAmount',
        'customer_note': 'customerNote',
        'cancel_reason': 'cancelReason',
        'warehouse_code': 'warehouseCode',
        'customer_id_ref': 'customerIdRef',
        'insurance_fee': 'insuranceFee',
        'express_type': 'expressType',
        'payment_pay_id': 'paymentPayId',
        'platform_name': 'platformName',
        'check_point': 'checkPoint',
        'items': 'items'
    }

    def __init__(self, dimension=None, ship_from=None, ship_to=None, bill=None, order_ref=None, seller_order_ref=None, tracking_reference=None, order_time=None, gross_weight=None, net_weight=None, total_price=None, currency='RMB', mass_unit='Kilogram', length_unit='Centimetre', domestic_delivery_company='YTO', created_at=None, updated_at=None, pay_method=None, pay_merchant_name=None, pay_amount=None, pay_id=None, paid_at=None, products_total_tax=None, shipping_cost=None, non_cash_deduction_amount=None, customer_note=None, cancel_reason=None, warehouse_code=None, customer_id_ref=None, insurance_fee=None, express_type=None, payment_pay_id=None, platform_name='youzan', check_point=None, items=None, local_vars_configuration=None):  # noqa: E501
        """PackageUpdate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._dimension = None
        self._ship_from = None
        self._ship_to = None
        self._bill = None
        self._order_ref = None
        self._seller_order_ref = None
        self._tracking_reference = None
        self._order_time = None
        self._gross_weight = None
        self._net_weight = None
        self._total_price = None
        self._currency = None
        self._mass_unit = None
        self._length_unit = None
        self._domestic_delivery_company = None
        self._created_at = None
        self._updated_at = None
        self._pay_method = None
        self._pay_merchant_name = None
        self._pay_amount = None
        self._pay_id = None
        self._paid_at = None
        self._products_total_tax = None
        self._shipping_cost = None
        self._non_cash_deduction_amount = None
        self._customer_note = None
        self._cancel_reason = None
        self._warehouse_code = None
        self._customer_id_ref = None
        self._insurance_fee = None
        self._express_type = None
        self._payment_pay_id = None
        self._platform_name = None
        self._check_point = None
        self._items = None
        self.discriminator = None

        if dimension is not None:
            self.dimension = dimension
        if ship_from is not None:
            self.ship_from = ship_from
        if ship_to is not None:
            self.ship_to = ship_to
        if bill is not None:
            self.bill = bill
        if order_ref is not None:
            self.order_ref = order_ref
        if seller_order_ref is not None:
            self.seller_order_ref = seller_order_ref
        self.tracking_reference = tracking_reference
        if order_time is not None:
            self.order_time = order_time
        if gross_weight is not None:
            self.gross_weight = gross_weight
        if net_weight is not None:
            self.net_weight = net_weight
        if total_price is not None:
            self.total_price = total_price
        if currency is not None:
            self.currency = currency
        if mass_unit is not None:
            self.mass_unit = mass_unit
        if length_unit is not None:
            self.length_unit = length_unit
        if domestic_delivery_company is not None:
            self.domestic_delivery_company = domestic_delivery_company
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if pay_method is not None:
            self.pay_method = pay_method
        if pay_merchant_name is not None:
            self.pay_merchant_name = pay_merchant_name
        if pay_amount is not None:
            self.pay_amount = pay_amount
        if pay_id is not None:
            self.pay_id = pay_id
        if paid_at is not None:
            self.paid_at = paid_at
        if products_total_tax is not None:
            self.products_total_tax = products_total_tax
        if shipping_cost is not None:
            self.shipping_cost = shipping_cost
        if non_cash_deduction_amount is not None:
            self.non_cash_deduction_amount = non_cash_deduction_amount
        if customer_note is not None:
            self.customer_note = customer_note
        if cancel_reason is not None:
            self.cancel_reason = cancel_reason
        if warehouse_code is not None:
            self.warehouse_code = warehouse_code
        if customer_id_ref is not None:
            self.customer_id_ref = customer_id_ref
        if insurance_fee is not None:
            self.insurance_fee = insurance_fee
        if express_type is not None:
            self.express_type = express_type
        if payment_pay_id is not None:
            self.payment_pay_id = payment_pay_id
        if platform_name is not None:
            self.platform_name = platform_name
        if check_point is not None:
            self.check_point = check_point
        if items is not None:
            self.items = items

    @property
    def dimension(self):
        """Gets the dimension of this PackageUpdate.  # noqa: E501


        :return: The dimension of this PackageUpdate.  # noqa: E501
        :rtype: Dimension
        """
        return self._dimension

    @dimension.setter
    def dimension(self, dimension):
        """Sets the dimension of this PackageUpdate.


        :param dimension: The dimension of this PackageUpdate.  # noqa: E501
        :type: Dimension
        """

        self._dimension = dimension

    @property
    def ship_from(self):
        """Gets the ship_from of this PackageUpdate.  # noqa: E501


        :return: The ship_from of this PackageUpdate.  # noqa: E501
        :rtype: Address
        """
        return self._ship_from

    @ship_from.setter
    def ship_from(self, ship_from):
        """Sets the ship_from of this PackageUpdate.


        :param ship_from: The ship_from of this PackageUpdate.  # noqa: E501
        :type: Address
        """

        self._ship_from = ship_from

    @property
    def ship_to(self):
        """Gets the ship_to of this PackageUpdate.  # noqa: E501


        :return: The ship_to of this PackageUpdate.  # noqa: E501
        :rtype: Address
        """
        return self._ship_to

    @ship_to.setter
    def ship_to(self, ship_to):
        """Sets the ship_to of this PackageUpdate.


        :param ship_to: The ship_to of this PackageUpdate.  # noqa: E501
        :type: Address
        """

        self._ship_to = ship_to

    @property
    def bill(self):
        """Gets the bill of this PackageUpdate.  # noqa: E501


        :return: The bill of this PackageUpdate.  # noqa: E501
        :rtype: Address
        """
        return self._bill

    @bill.setter
    def bill(self, bill):
        """Sets the bill of this PackageUpdate.


        :param bill: The bill of this PackageUpdate.  # noqa: E501
        :type: Address
        """

        self._bill = bill

    @property
    def order_ref(self):
        """Gets the order_ref of this PackageUpdate.  # noqa: E501

        Order reference number. Default is from Odoo.  # noqa: E501

        :return: The order_ref of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._order_ref

    @order_ref.setter
    def order_ref(self, order_ref):
        """Sets the order_ref of this PackageUpdate.

        Order reference number. Default is from Odoo.  # noqa: E501

        :param order_ref: The order_ref of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._order_ref = order_ref

    @property
    def seller_order_ref(self):
        """Gets the seller_order_ref of this PackageUpdate.  # noqa: E501

        Order reference number. Also could be from retailers, e.g. Youzan.  # noqa: E501

        :return: The seller_order_ref of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._seller_order_ref

    @seller_order_ref.setter
    def seller_order_ref(self, seller_order_ref):
        """Sets the seller_order_ref of this PackageUpdate.

        Order reference number. Also could be from retailers, e.g. Youzan.  # noqa: E501

        :param seller_order_ref: The seller_order_ref of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._seller_order_ref = seller_order_ref

    @property
    def tracking_reference(self):
        """Gets the tracking_reference of this PackageUpdate.  # noqa: E501


        :return: The tracking_reference of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._tracking_reference

    @tracking_reference.setter
    def tracking_reference(self, tracking_reference):
        """Sets the tracking_reference of this PackageUpdate.


        :param tracking_reference: The tracking_reference of this PackageUpdate.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and tracking_reference is None:  # noqa: E501
            raise ValueError("Invalid value for `tracking_reference`, must not be `None`")  # noqa: E501

        self._tracking_reference = tracking_reference

    @property
    def order_time(self):
        """Gets the order_time of this PackageUpdate.  # noqa: E501

        ISO 8601 format, '2019-01-19T18:30:52.442118+00:00' or '2019-01-19T18:30:52+00:00'  # noqa: E501

        :return: The order_time of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._order_time

    @order_time.setter
    def order_time(self, order_time):
        """Sets the order_time of this PackageUpdate.

        ISO 8601 format, '2019-01-19T18:30:52.442118+00:00' or '2019-01-19T18:30:52+00:00'  # noqa: E501

        :param order_time: The order_time of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._order_time = order_time

    @property
    def gross_weight(self):
        """Gets the gross_weight of this PackageUpdate.  # noqa: E501

        Use Kilogram as the basic unit of mass.  # noqa: E501

        :return: The gross_weight of this PackageUpdate.  # noqa: E501
        :rtype: float
        """
        return self._gross_weight

    @gross_weight.setter
    def gross_weight(self, gross_weight):
        """Sets the gross_weight of this PackageUpdate.

        Use Kilogram as the basic unit of mass.  # noqa: E501

        :param gross_weight: The gross_weight of this PackageUpdate.  # noqa: E501
        :type: float
        """

        self._gross_weight = gross_weight

    @property
    def net_weight(self):
        """Gets the net_weight of this PackageUpdate.  # noqa: E501

        Use Kilogram as the basic unit of mass.  # noqa: E501

        :return: The net_weight of this PackageUpdate.  # noqa: E501
        :rtype: float
        """
        return self._net_weight

    @net_weight.setter
    def net_weight(self, net_weight):
        """Sets the net_weight of this PackageUpdate.

        Use Kilogram as the basic unit of mass.  # noqa: E501

        :param net_weight: The net_weight of this PackageUpdate.  # noqa: E501
        :type: float
        """

        self._net_weight = net_weight

    @property
    def total_price(self):
        """Gets the total_price of this PackageUpdate.  # noqa: E501

        The total price of this package.  # noqa: E501

        :return: The total_price of this PackageUpdate.  # noqa: E501
        :rtype: float
        """
        return self._total_price

    @total_price.setter
    def total_price(self, total_price):
        """Sets the total_price of this PackageUpdate.

        The total price of this package.  # noqa: E501

        :param total_price: The total_price of this PackageUpdate.  # noqa: E501
        :type: float
        """

        self._total_price = total_price

    @property
    def currency(self):
        """Gets the currency of this PackageUpdate.  # noqa: E501

        Price makes sense under an explicit currency, available options: RMB, CNY, USD, GBP  # noqa: E501

        :return: The currency of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this PackageUpdate.

        Price makes sense under an explicit currency, available options: RMB, CNY, USD, GBP  # noqa: E501

        :param currency: The currency of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def mass_unit(self):
        """Gets the mass_unit of this PackageUpdate.  # noqa: E501

        weight Unit of measurement  # noqa: E501

        :return: The mass_unit of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._mass_unit

    @mass_unit.setter
    def mass_unit(self, mass_unit):
        """Sets the mass_unit of this PackageUpdate.

        weight Unit of measurement  # noqa: E501

        :param mass_unit: The mass_unit of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._mass_unit = mass_unit

    @property
    def length_unit(self):
        """Gets the length_unit of this PackageUpdate.  # noqa: E501

        length Unit of measurement  # noqa: E501

        :return: The length_unit of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._length_unit

    @length_unit.setter
    def length_unit(self, length_unit):
        """Sets the length_unit of this PackageUpdate.

        length Unit of measurement  # noqa: E501

        :param length_unit: The length_unit of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._length_unit = length_unit

    @property
    def domestic_delivery_company(self):
        """Gets the domestic_delivery_company of this PackageUpdate.  # noqa: E501

        the domestic delivery vendor, 2 available options: [SF, YTO]  # noqa: E501

        :return: The domestic_delivery_company of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._domestic_delivery_company

    @domestic_delivery_company.setter
    def domestic_delivery_company(self, domestic_delivery_company):
        """Sets the domestic_delivery_company of this PackageUpdate.

        the domestic delivery vendor, 2 available options: [SF, YTO]  # noqa: E501

        :param domestic_delivery_company: The domestic_delivery_company of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._domestic_delivery_company = domestic_delivery_company

    @property
    def created_at(self):
        """Gets the created_at of this PackageUpdate.  # noqa: E501

        The time when current order was created. ISO_8601 format  # noqa: E501

        :return: The created_at of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PackageUpdate.

        The time when current order was created. ISO_8601 format  # noqa: E501

        :param created_at: The created_at of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this PackageUpdate.  # noqa: E501

        The time when current order was updated. ISO_8601 format  # noqa: E501

        :return: The updated_at of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PackageUpdate.

        The time when current order was updated. ISO_8601 format  # noqa: E501

        :param updated_at: The updated_at of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    @property
    def pay_method(self):
        """Gets the pay_method of this PackageUpdate.  # noqa: E501


        :return: The pay_method of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._pay_method

    @pay_method.setter
    def pay_method(self, pay_method):
        """Sets the pay_method of this PackageUpdate.


        :param pay_method: The pay_method of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._pay_method = pay_method

    @property
    def pay_merchant_name(self):
        """Gets the pay_merchant_name of this PackageUpdate.  # noqa: E501


        :return: The pay_merchant_name of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._pay_merchant_name

    @pay_merchant_name.setter
    def pay_merchant_name(self, pay_merchant_name):
        """Sets the pay_merchant_name of this PackageUpdate.


        :param pay_merchant_name: The pay_merchant_name of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._pay_merchant_name = pay_merchant_name

    @property
    def pay_amount(self):
        """Gets the pay_amount of this PackageUpdate.  # noqa: E501

        The amount of final paid.  # noqa: E501

        :return: The pay_amount of this PackageUpdate.  # noqa: E501
        :rtype: float
        """
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, pay_amount):
        """Sets the pay_amount of this PackageUpdate.

        The amount of final paid.  # noqa: E501

        :param pay_amount: The pay_amount of this PackageUpdate.  # noqa: E501
        :type: float
        """

        self._pay_amount = pay_amount

    @property
    def pay_id(self):
        """Gets the pay_id of this PackageUpdate.  # noqa: E501

        The payment number generated by eCommerce platform such as Youzan  # noqa: E501

        :return: The pay_id of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._pay_id

    @pay_id.setter
    def pay_id(self, pay_id):
        """Sets the pay_id of this PackageUpdate.

        The payment number generated by eCommerce platform such as Youzan  # noqa: E501

        :param pay_id: The pay_id of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._pay_id = pay_id

    @property
    def paid_at(self):
        """Gets the paid_at of this PackageUpdate.  # noqa: E501

        The time when the pay was made. ISO_8601 format  # noqa: E501

        :return: The paid_at of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._paid_at

    @paid_at.setter
    def paid_at(self, paid_at):
        """Sets the paid_at of this PackageUpdate.

        The time when the pay was made. ISO_8601 format  # noqa: E501

        :param paid_at: The paid_at of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._paid_at = paid_at

    @property
    def products_total_tax(self):
        """Gets the products_total_tax of this PackageUpdate.  # noqa: E501

        The sum tax of all products in current order, including Non-cash deduction amount.  # noqa: E501

        :return: The products_total_tax of this PackageUpdate.  # noqa: E501
        :rtype: float
        """
        return self._products_total_tax

    @products_total_tax.setter
    def products_total_tax(self, products_total_tax):
        """Sets the products_total_tax of this PackageUpdate.

        The sum tax of all products in current order, including Non-cash deduction amount.  # noqa: E501

        :param products_total_tax: The products_total_tax of this PackageUpdate.  # noqa: E501
        :type: float
        """

        self._products_total_tax = products_total_tax

    @property
    def shipping_cost(self):
        """Gets the shipping_cost of this PackageUpdate.  # noqa: E501

        The shipping cost of current order, excluding the shipping cost on each contained products. If delivery free, just set 0.  # noqa: E501

        :return: The shipping_cost of this PackageUpdate.  # noqa: E501
        :rtype: float
        """
        return self._shipping_cost

    @shipping_cost.setter
    def shipping_cost(self, shipping_cost):
        """Sets the shipping_cost of this PackageUpdate.

        The shipping cost of current order, excluding the shipping cost on each contained products. If delivery free, just set 0.  # noqa: E501

        :param shipping_cost: The shipping_cost of this PackageUpdate.  # noqa: E501
        :type: float
        """

        self._shipping_cost = shipping_cost

    @property
    def non_cash_deduction_amount(self):
        """Gets the non_cash_deduction_amount of this PackageUpdate.  # noqa: E501

        Amount that deducted by non-cash, e.g. member points, virtual currency, voucher code, etc.  # noqa: E501

        :return: The non_cash_deduction_amount of this PackageUpdate.  # noqa: E501
        :rtype: float
        """
        return self._non_cash_deduction_amount

    @non_cash_deduction_amount.setter
    def non_cash_deduction_amount(self, non_cash_deduction_amount):
        """Sets the non_cash_deduction_amount of this PackageUpdate.

        Amount that deducted by non-cash, e.g. member points, virtual currency, voucher code, etc.  # noqa: E501

        :param non_cash_deduction_amount: The non_cash_deduction_amount of this PackageUpdate.  # noqa: E501
        :type: float
        """

        self._non_cash_deduction_amount = non_cash_deduction_amount

    @property
    def customer_note(self):
        """Gets the customer_note of this PackageUpdate.  # noqa: E501

        The special note from the buyer.  # noqa: E501

        :return: The customer_note of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._customer_note

    @customer_note.setter
    def customer_note(self, customer_note):
        """Sets the customer_note of this PackageUpdate.

        The special note from the buyer.  # noqa: E501

        :param customer_note: The customer_note of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._customer_note = customer_note

    @property
    def cancel_reason(self):
        """Gets the cancel_reason of this PackageUpdate.  # noqa: E501

        The cancel reason of current package.  # noqa: E501

        :return: The cancel_reason of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._cancel_reason

    @cancel_reason.setter
    def cancel_reason(self, cancel_reason):
        """Sets the cancel_reason of this PackageUpdate.

        The cancel reason of current package.  # noqa: E501

        :param cancel_reason: The cancel_reason of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._cancel_reason = cancel_reason

    @property
    def warehouse_code(self):
        """Gets the warehouse_code of this PackageUpdate.  # noqa: E501

        The code of warehouse for this package  # noqa: E501

        :return: The warehouse_code of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._warehouse_code

    @warehouse_code.setter
    def warehouse_code(self, warehouse_code):
        """Sets the warehouse_code of this PackageUpdate.

        The code of warehouse for this package  # noqa: E501

        :param warehouse_code: The warehouse_code of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._warehouse_code = warehouse_code

    @property
    def customer_id_ref(self):
        """Gets the customer_id_ref of this PackageUpdate.  # noqa: E501

        The ID of buyer on current third party platform.  # noqa: E501

        :return: The customer_id_ref of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._customer_id_ref

    @customer_id_ref.setter
    def customer_id_ref(self, customer_id_ref):
        """Sets the customer_id_ref of this PackageUpdate.

        The ID of buyer on current third party platform.  # noqa: E501

        :param customer_id_ref: The customer_id_ref of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._customer_id_ref = customer_id_ref

    @property
    def insurance_fee(self):
        """Gets the insurance_fee of this PackageUpdate.  # noqa: E501

        The insurance fee of current shipping.  # noqa: E501

        :return: The insurance_fee of this PackageUpdate.  # noqa: E501
        :rtype: float
        """
        return self._insurance_fee

    @insurance_fee.setter
    def insurance_fee(self, insurance_fee):
        """Sets the insurance_fee of this PackageUpdate.

        The insurance fee of current shipping.  # noqa: E501

        :param insurance_fee: The insurance_fee of this PackageUpdate.  # noqa: E501
        :type: float
        """

        self._insurance_fee = insurance_fee

    @property
    def express_type(self):
        """Gets the express_type of this PackageUpdate.  # noqa: E501

        BC for 901, CC for 902  # noqa: E501

        :return: The express_type of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._express_type

    @express_type.setter
    def express_type(self, express_type):
        """Sets the express_type of this PackageUpdate.

        BC for 901, CC for 902  # noqa: E501

        :param express_type: The express_type of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._express_type = express_type

    @property
    def payment_pay_id(self):
        """Gets the payment_pay_id of this PackageUpdate.  # noqa: E501

        The payment number generated by payment tool such as WeChat Pay  # noqa: E501

        :return: The payment_pay_id of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._payment_pay_id

    @payment_pay_id.setter
    def payment_pay_id(self, payment_pay_id):
        """Sets the payment_pay_id of this PackageUpdate.

        The payment number generated by payment tool such as WeChat Pay  # noqa: E501

        :param payment_pay_id: The payment_pay_id of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._payment_pay_id = payment_pay_id

    @property
    def platform_name(self):
        """Gets the platform_name of this PackageUpdate.  # noqa: E501

        e-commerce platform name, available options: [youzan,pdd,nomad]  # noqa: E501

        :return: The platform_name of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._platform_name

    @platform_name.setter
    def platform_name(self, platform_name):
        """Sets the platform_name of this PackageUpdate.

        e-commerce platform name, available options: [youzan,pdd,nomad]  # noqa: E501

        :param platform_name: The platform_name of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._platform_name = platform_name

    @property
    def check_point(self):
        """Gets the check_point of this PackageUpdate.  # noqa: E501

        log express check point  # noqa: E501

        :return: The check_point of this PackageUpdate.  # noqa: E501
        :rtype: str
        """
        return self._check_point

    @check_point.setter
    def check_point(self, check_point):
        """Sets the check_point of this PackageUpdate.

        log express check point  # noqa: E501

        :param check_point: The check_point of this PackageUpdate.  # noqa: E501
        :type: str
        """

        self._check_point = check_point

    @property
    def items(self):
        """Gets the items of this PackageUpdate.  # noqa: E501

        Contents of package  # noqa: E501

        :return: The items of this PackageUpdate.  # noqa: E501
        :rtype: list[PackageItem]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this PackageUpdate.

        Contents of package  # noqa: E501

        :param items: The items of this PackageUpdate.  # noqa: E501
        :type: list[PackageItem]
        """

        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PackageUpdate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PackageUpdate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nomad_pilot_cli.configuration import Configuration


class ApiResponseData(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'waybill_id': 'str',
        'order_sn': 'str',
        'order_ref': 'str',
        'seller_order_ref': 'str',
        'domestic_delivery_company': 'str',
        'delivery_status': 'str',
        'delivery_note': 'str',
        'delivery_slip_url': 'str',
        'tracking_url': 'str',
        'check_points': 'list[str]'
    }

    attribute_map = {
        'waybill_id': 'waybillId',
        'order_sn': 'orderSn',
        'order_ref': 'orderRef',
        'seller_order_ref': 'sellerOrderRef',
        'domestic_delivery_company': 'domesticDeliveryCompany',
        'delivery_status': 'deliveryStatus',
        'delivery_note': 'deliveryNote',
        'delivery_slip_url': 'deliverySlipUrl',
        'tracking_url': 'trackingUrl',
        'check_points': 'checkPoints'
    }

    def __init__(self, waybill_id=None, order_sn=None, order_ref=None, seller_order_ref=None, domestic_delivery_company=None, delivery_status=None, delivery_note=None, delivery_slip_url=None, tracking_url=None, check_points=None, local_vars_configuration=None):  # noqa: E501
        """ApiResponseData - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._waybill_id = None
        self._order_sn = None
        self._order_ref = None
        self._seller_order_ref = None
        self._domestic_delivery_company = None
        self._delivery_status = None
        self._delivery_note = None
        self._delivery_slip_url = None
        self._tracking_url = None
        self._check_points = None
        self.discriminator = None

        if waybill_id is not None:
            self.waybill_id = waybill_id
        if order_sn is not None:
            self.order_sn = order_sn
        if order_ref is not None:
            self.order_ref = order_ref
        if seller_order_ref is not None:
            self.seller_order_ref = seller_order_ref
        if domestic_delivery_company is not None:
            self.domestic_delivery_company = domestic_delivery_company
        if delivery_status is not None:
            self.delivery_status = delivery_status
        if delivery_note is not None:
            self.delivery_note = delivery_note
        if delivery_slip_url is not None:
            self.delivery_slip_url = delivery_slip_url
        if tracking_url is not None:
            self.tracking_url = tracking_url
        if check_points is not None:
            self.check_points = check_points

    @property
    def waybill_id(self):
        """Gets the waybill_id of this ApiResponseData.  # noqa: E501


        :return: The waybill_id of this ApiResponseData.  # noqa: E501
        :rtype: str
        """
        return self._waybill_id

    @waybill_id.setter
    def waybill_id(self, waybill_id):
        """Sets the waybill_id of this ApiResponseData.


        :param waybill_id: The waybill_id of this ApiResponseData.  # noqa: E501
        :type: str
        """

        self._waybill_id = waybill_id

    @property
    def order_sn(self):
        """Gets the order_sn of this ApiResponseData.  # noqa: E501

        Deprecated. Replaced by 'orderRef'.  # noqa: E501

        :return: The order_sn of this ApiResponseData.  # noqa: E501
        :rtype: str
        """
        return self._order_sn

    @order_sn.setter
    def order_sn(self, order_sn):
        """Sets the order_sn of this ApiResponseData.

        Deprecated. Replaced by 'orderRef'.  # noqa: E501

        :param order_sn: The order_sn of this ApiResponseData.  # noqa: E501
        :type: str
        """

        self._order_sn = order_sn

    @property
    def order_ref(self):
        """Gets the order_ref of this ApiResponseData.  # noqa: E501

        Order reference number. Default is from Odoo.  # noqa: E501

        :return: The order_ref of this ApiResponseData.  # noqa: E501
        :rtype: str
        """
        return self._order_ref

    @order_ref.setter
    def order_ref(self, order_ref):
        """Sets the order_ref of this ApiResponseData.

        Order reference number. Default is from Odoo.  # noqa: E501

        :param order_ref: The order_ref of this ApiResponseData.  # noqa: E501
        :type: str
        """

        self._order_ref = order_ref

    @property
    def seller_order_ref(self):
        """Gets the seller_order_ref of this ApiResponseData.  # noqa: E501

        Order reference number. Also could be from retailers, e.g. Youzan.  # noqa: E501

        :return: The seller_order_ref of this ApiResponseData.  # noqa: E501
        :rtype: str
        """
        return self._seller_order_ref

    @seller_order_ref.setter
    def seller_order_ref(self, seller_order_ref):
        """Sets the seller_order_ref of this ApiResponseData.

        Order reference number. Also could be from retailers, e.g. Youzan.  # noqa: E501

        :param seller_order_ref: The seller_order_ref of this ApiResponseData.  # noqa: E501
        :type: str
        """

        self._seller_order_ref = seller_order_ref

    @property
    def domestic_delivery_company(self):
        """Gets the domestic_delivery_company of this ApiResponseData.  # noqa: E501

        the domestic delivery vender for sinotrans  # noqa: E501

        :return: The domestic_delivery_company of this ApiResponseData.  # noqa: E501
        :rtype: str
        """
        return self._domestic_delivery_company

    @domestic_delivery_company.setter
    def domestic_delivery_company(self, domestic_delivery_company):
        """Sets the domestic_delivery_company of this ApiResponseData.

        the domestic delivery vender for sinotrans  # noqa: E501

        :param domestic_delivery_company: The domestic_delivery_company of this ApiResponseData.  # noqa: E501
        :type: str
        """

        self._domestic_delivery_company = domestic_delivery_company

    @property
    def delivery_status(self):
        """Gets the delivery_status of this ApiResponseData.  # noqa: E501

        The delivery status of one package, 9 possible values are below statues will be loaded into PilotDeliveryStatus().statuses. @PREPARE_ORDER @SORT_ORDER @PACK_ORDER @ORDER_OUTBOUND @CUSTOM_CLEAR @CUSTOM_CLEAR_COMPLETE @FLIGHT_DEPARTURE @FLIGHT_ARRIVE @DOMESTIC_DELIVERY   # noqa: E501

        :return: The delivery_status of this ApiResponseData.  # noqa: E501
        :rtype: str
        """
        return self._delivery_status

    @delivery_status.setter
    def delivery_status(self, delivery_status):
        """Sets the delivery_status of this ApiResponseData.

        The delivery status of one package, 9 possible values are below statues will be loaded into PilotDeliveryStatus().statuses. @PREPARE_ORDER @SORT_ORDER @PACK_ORDER @ORDER_OUTBOUND @CUSTOM_CLEAR @CUSTOM_CLEAR_COMPLETE @FLIGHT_DEPARTURE @FLIGHT_ARRIVE @DOMESTIC_DELIVERY   # noqa: E501

        :param delivery_status: The delivery_status of this ApiResponseData.  # noqa: E501
        :type: str
        """

        self._delivery_status = delivery_status

    @property
    def delivery_note(self):
        """Gets the delivery_note of this ApiResponseData.  # noqa: E501

        A note marked by the carrier, could be changed at any time.  # noqa: E501

        :return: The delivery_note of this ApiResponseData.  # noqa: E501
        :rtype: str
        """
        return self._delivery_note

    @delivery_note.setter
    def delivery_note(self, delivery_note):
        """Sets the delivery_note of this ApiResponseData.

        A note marked by the carrier, could be changed at any time.  # noqa: E501

        :param delivery_note: The delivery_note of this ApiResponseData.  # noqa: E501
        :type: str
        """

        self._delivery_note = delivery_note

    @property
    def delivery_slip_url(self):
        """Gets the delivery_slip_url of this ApiResponseData.  # noqa: E501

        The URL of delivery slip.  # noqa: E501

        :return: The delivery_slip_url of this ApiResponseData.  # noqa: E501
        :rtype: str
        """
        return self._delivery_slip_url

    @delivery_slip_url.setter
    def delivery_slip_url(self, delivery_slip_url):
        """Sets the delivery_slip_url of this ApiResponseData.

        The URL of delivery slip.  # noqa: E501

        :param delivery_slip_url: The delivery_slip_url of this ApiResponseData.  # noqa: E501
        :type: str
        """

        self._delivery_slip_url = delivery_slip_url

    @property
    def tracking_url(self):
        """Gets the tracking_url of this ApiResponseData.  # noqa: E501

        The URL of waybill tracking.  # noqa: E501

        :return: The tracking_url of this ApiResponseData.  # noqa: E501
        :rtype: str
        """
        return self._tracking_url

    @tracking_url.setter
    def tracking_url(self, tracking_url):
        """Sets the tracking_url of this ApiResponseData.

        The URL of waybill tracking.  # noqa: E501

        :param tracking_url: The tracking_url of this ApiResponseData.  # noqa: E501
        :type: str
        """

        self._tracking_url = tracking_url

    @property
    def check_points(self):
        """Gets the check_points of this ApiResponseData.  # noqa: E501

        The details of express checkpoints.  # noqa: E501

        :return: The check_points of this ApiResponseData.  # noqa: E501
        :rtype: list[str]
        """
        return self._check_points

    @check_points.setter
    def check_points(self, check_points):
        """Sets the check_points of this ApiResponseData.

        The details of express checkpoints.  # noqa: E501

        :param check_points: The check_points of this ApiResponseData.  # noqa: E501
        :type: list[str]
        """

        self._check_points = check_points

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiResponseData):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApiResponseData):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nomad_pilot_cli.configuration import Configuration


class PackageItemQuick(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'sku_number': 'str',
        'barcode': 'str',
        'quantity': 'int',
        'price': 'float'
    }

    attribute_map = {
        'sku_number': 'skuNumber',
        'barcode': 'barcode',
        'quantity': 'quantity',
        'price': 'price'
    }

    def __init__(self, sku_number=None, barcode=None, quantity=None, price=None, local_vars_configuration=None):  # noqa: E501
        """PackageItemQuick - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._sku_number = None
        self._barcode = None
        self._quantity = None
        self._price = None
        self.discriminator = None

        self.sku_number = sku_number
        if barcode is not None:
            self.barcode = barcode
        self.quantity = quantity
        self.price = price

    @property
    def sku_number(self):
        """Gets the sku_number of this PackageItemQuick.  # noqa: E501


        :return: The sku_number of this PackageItemQuick.  # noqa: E501
        :rtype: str
        """
        return self._sku_number

    @sku_number.setter
    def sku_number(self, sku_number):
        """Sets the sku_number of this PackageItemQuick.


        :param sku_number: The sku_number of this PackageItemQuick.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and sku_number is None:  # noqa: E501
            raise ValueError("Invalid value for `sku_number`, must not be `None`")  # noqa: E501

        self._sku_number = sku_number

    @property
    def barcode(self):
        """Gets the barcode of this PackageItemQuick.  # noqa: E501


        :return: The barcode of this PackageItemQuick.  # noqa: E501
        :rtype: str
        """
        return self._barcode

    @barcode.setter
    def barcode(self, barcode):
        """Sets the barcode of this PackageItemQuick.


        :param barcode: The barcode of this PackageItemQuick.  # noqa: E501
        :type: str
        """

        self._barcode = barcode

    @property
    def quantity(self):
        """Gets the quantity of this PackageItemQuick.  # noqa: E501


        :return: The quantity of this PackageItemQuick.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this PackageItemQuick.


        :param quantity: The quantity of this PackageItemQuick.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and quantity is None:  # noqa: E501
            raise ValueError("Invalid value for `quantity`, must not be `None`")  # noqa: E501

        self._quantity = quantity

    @property
    def price(self):
        """Gets the price of this PackageItemQuick.  # noqa: E501


        :return: The price of this PackageItemQuick.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this PackageItemQuick.


        :param price: The price of this PackageItemQuick.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and price is None:  # noqa: E501
            raise ValueError("Invalid value for `price`, must not be `None`")  # noqa: E501

        self._price = price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PackageItemQuick):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PackageItemQuick):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import nomad_pilot_cli
from nomad_pilot_cli.models.package_items import PackageItems  # noqa: E501
from nomad_pilot_cli.rest import ApiException

class TestPackageItems(unittest.TestCase):
    """PackageItems unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PackageItems
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = nomad_pilot_cli.models.package_items.PackageItems()  # noqa: E501
        if include_optional :
            return PackageItems(
                items = [
                    nomad_pilot_cli.models.package_item.PackageItem(
                        name = '0', 
                        name_cn = '0', 
                        barcode = '0', 
                        sku_number = 'SMK123', 
                        quantity = 7, 
                        price = 21.3, 
                        brand = '0', 
                        quantity_uom = '50G', 
                        hs_code = '0', 
                        country_of_origin = '0', 
                        goldjet = nomad_pilot_cli.models.goldjet.Goldjet(
                            goods_ptcode = '0', ), 
                        gross_weight = 1.337, 
                        net_weight = 1.337, 
                        customs_unit_code = '142, 007, 瓶, ...', 
                        customs_unit_code_package = '142, 011, 140', 
                        customs_unit_code_weight = '035', 
                        customs_filing_id = '0', 
                        spec = '25mm', 
                        model = 'iPhone XR', 
                        ingredients = '发酵乳杆菌Lc40（CECT5716），麦芽糊精，蔗糖，抗坏血酸钠', )
                    ]
            )
        else :
            return PackageItems(
        )

    def testPackageItems(self):
        """Test PackageItems"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nomad_pilot_cli.configuration import Configuration


class PackageItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'name_cn': 'str',
        'barcode': 'str',
        'sku_number': 'str',
        'quantity': 'int',
        'price': 'float',
        'brand': 'str',
        'quantity_uom': 'str',
        'hs_code': 'str',
        'country_of_origin': 'str',
        'goldjet': 'Goldjet',
        'gross_weight': 'float',
        'net_weight': 'float',
        'customs_unit_code': 'str',
        'customs_unit_code_package': 'str',
        'customs_unit_code_weight': 'str',
        'customs_filing_id': 'str',
        'spec': 'str',
        'model': 'str',
        'ingredients': 'str'
    }

    attribute_map = {
        'name': 'name',
        'name_cn': 'nameCn',
        'barcode': 'barcode',
        'sku_number': 'skuNumber',
        'quantity': 'quantity',
        'price': 'price',
        'brand': 'brand',
        'quantity_uom': 'quantityUom',
        'hs_code': 'hsCode',
        'country_of_origin': 'countryOfOrigin',
        'goldjet': 'goldjet',
        'gross_weight': 'grossWeight',
        'net_weight': 'netWeight',
        'customs_unit_code': 'customsUnitCode',
        'customs_unit_code_package': 'customsUnitCodePackage',
        'customs_unit_code_weight': 'customsUnitCodeWeight',
        'customs_filing_id': 'customsFilingId',
        'spec': 'spec',
        'model': 'model',
        'ingredients': 'ingredients'
    }

    def __init__(self, name=None, name_cn=None, barcode=None, sku_number=None, quantity=None, price=None, brand=None, quantity_uom=None, hs_code=None, country_of_origin=None, goldjet=None, gross_weight=None, net_weight=None, customs_unit_code=None, customs_unit_code_package=None, customs_unit_code_weight='035', customs_filing_id=None, spec=None, model=None, ingredients=None, local_vars_configuration=None):  # noqa: E501
        """PackageItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._name_cn = None
        self._barcode = None
        self._sku_number = None
        self._quantity = None
        self._price = None
        self._brand = None
        self._quantity_uom = None
        self._hs_code = None
        self._country_of_origin = None
        self._goldjet = None
        self._gross_weight = None
        self._net_weight = None
        self._customs_unit_code = None
        self._customs_unit_code_package = None
        self._customs_unit_code_weight = None
        self._customs_filing_id = None
        self._spec = None
        self._model = None
        self._ingredients = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if name_cn is not None:
            self.name_cn = name_cn
        if barcode is not None:
            self.barcode = barcode
        if sku_number is not None:
            self.sku_number = sku_number
        if quantity is not None:
            self.quantity = quantity
        if price is not None:
            self.price = price
        if brand is not None:
            self.brand = brand
        if quantity_uom is not None:
            self.quantity_uom = quantity_uom
        if hs_code is not None:
            self.hs_code = hs_code
        if country_of_origin is not None:
            self.country_of_origin = country_of_origin
        if goldjet is not None:
            self.goldjet = goldjet
        if gross_weight is not None:
            self.gross_weight = gross_weight
        if net_weight is not None:
            self.net_weight = net_weight
        if customs_unit_code is not None:
            self.customs_unit_code = customs_unit_code
        if customs_unit_code_package is not None:
            self.customs_unit_code_package = customs_unit_code_package
        if customs_unit_code_weight is not None:
            self.customs_unit_code_weight = customs_unit_code_weight
        if customs_filing_id is not None:
            self.customs_filing_id = customs_filing_id
        if spec is not None:
            self.spec = spec
        if model is not None:
            self.model = model
        if ingredients is not None:
            self.ingredients = ingredients

    @property
    def name(self):
        """Gets the name of this PackageItem.  # noqa: E501


        :return: The name of this PackageItem.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PackageItem.


        :param name: The name of this PackageItem.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def name_cn(self):
        """Gets the name_cn of this PackageItem.  # noqa: E501

        The Chinese name of current product item  # noqa: E501

        :return: The name_cn of this PackageItem.  # noqa: E501
        :rtype: str
        """
        return self._name_cn

    @name_cn.setter
    def name_cn(self, name_cn):
        """Sets the name_cn of this PackageItem.

        The Chinese name of current product item  # noqa: E501

        :param name_cn: The name_cn of this PackageItem.  # noqa: E501
        :type: str
        """

        self._name_cn = name_cn

    @property
    def barcode(self):
        """Gets the barcode of this PackageItem.  # noqa: E501


        :return: The barcode of this PackageItem.  # noqa: E501
        :rtype: str
        """
        return self._barcode

    @barcode.setter
    def barcode(self, barcode):
        """Sets the barcode of this PackageItem.


        :param barcode: The barcode of this PackageItem.  # noqa: E501
        :type: str
        """

        self._barcode = barcode

    @property
    def sku_number(self):
        """Gets the sku_number of this PackageItem.  # noqa: E501


        :return: The sku_number of this PackageItem.  # noqa: E501
        :rtype: str
        """
        return self._sku_number

    @sku_number.setter
    def sku_number(self, sku_number):
        """Sets the sku_number of this PackageItem.


        :param sku_number: The sku_number of this PackageItem.  # noqa: E501
        :type: str
        """

        self._sku_number = sku_number

    @property
    def quantity(self):
        """Gets the quantity of this PackageItem.  # noqa: E501


        :return: The quantity of this PackageItem.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this PackageItem.


        :param quantity: The quantity of this PackageItem.  # noqa: E501
        :type: int
        """

        self._quantity = quantity

    @property
    def price(self):
        """Gets the price of this PackageItem.  # noqa: E501


        :return: The price of this PackageItem.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this PackageItem.


        :param price: The price of this PackageItem.  # noqa: E501
        :type: float
        """

        self._price = price

    @property
    def brand(self):
        """Gets the brand of this PackageItem.  # noqa: E501


        :return: The brand of this PackageItem.  # noqa: E501
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """Sets the brand of this PackageItem.


        :param brand: The brand of this PackageItem.  # noqa: E501
        :type: str
        """

        self._brand = brand

    @property
    def quantity_uom(self):
        """Gets the quantity_uom of this PackageItem.  # noqa: E501


        :return: The quantity_uom of this PackageItem.  # noqa: E501
        :rtype: str
        """
        return self._quantity_uom

    @quantity_uom.setter
    def quantity_uom(self, quantity_uom):
        """Sets the quantity_uom of this PackageItem.


        :param quantity_uom: The quantity_uom of this PackageItem.  # noqa: E501
        :type: str
        """

        self._quantity_uom = quantity_uom

    @property
    def hs_code(self):
        """Gets the hs_code of this PackageItem.  # noqa: E501


        :return: The hs_code of this PackageItem.  # noqa: E501
        :rtype: str
        """
        return self._hs_code

    @hs_code.setter
    def hs_code(self, hs_code):
        """Sets the hs_code of this PackageItem.


        :param hs_code: The hs_code of this PackageItem.  # noqa: E501
        :type: str
        """

        self._hs_code = hs_code

    @property
    def country_of_origin(self):
        """Gets the country_of_origin of this PackageItem.  # noqa: E501


        :return: The country_of_origin of this PackageItem.  # noqa: E501
        :rtype: str
        """
        return self._country_of_origin

    @country_of_origin.setter
    def country_of_origin(self, country_of_origin):
        """Sets the country_of_origin of this PackageItem.


        :param country_of_origin: The country_of_origin of this PackageItem.  # noqa: E501
        :type: str
        """

        self._country_of_origin = country_of_origin

    @property
    def goldjet(self):
        """Gets the goldjet of this PackageItem.  # noqa: E501


        :return: The goldjet of this PackageItem.  # noqa: E501
        :rtype: Goldjet
        """
        return self._goldjet

    @goldjet.setter
    def goldjet(self, goldjet):
        """Sets the goldjet of this PackageItem.


        :param goldjet: The goldjet of this PackageItem.  # noqa: E501
        :type: Goldjet
        """

        self._goldjet = goldjet

    @property
    def gross_weight(self):
        """Gets the gross_weight of this PackageItem.  # noqa: E501

        Use Kilogram as the basic unit of mass.  # noqa: E501

        :return: The gross_weight of this PackageItem.  # noqa: E501
        :rtype: float
        """
        return self._gross_weight

    @gross_weight.setter
    def gross_weight(self, gross_weight):
        """Sets the gross_weight of this PackageItem.

        Use Kilogram as the basic unit of mass.  # noqa: E501

        :param gross_weight: The gross_weight of this PackageItem.  # noqa: E501
        :type: float
        """

        self._gross_weight = gross_weight

    @property
    def net_weight(self):
        """Gets the net_weight of this PackageItem.  # noqa: E501

        Use Kilogram as the basic unit of mass.  # noqa: E501

        :return: The net_weight of this PackageItem.  # noqa: E501
        :rtype: float
        """
        return self._net_weight

    @net_weight.setter
    def net_weight(self, net_weight):
        """Sets the net_weight of this PackageItem.

        Use Kilogram as the basic unit of mass.  # noqa: E501

        :param net_weight: The net_weight of this PackageItem.  # noqa: E501
        :type: float
        """

        self._net_weight = net_weight

    @property
    def customs_unit_code(self):
        """Gets the customs_unit_code of this PackageItem.  # noqa: E501

        aka customsUnitCodeSKU. The quantity unit code of current sku for customs purpose. Both Chinese or number are ok.  # noqa: E501

        :return: The customs_unit_code of this PackageItem.  # noqa: E501
        :rtype: str
        """
        return self._customs_unit_code

    @customs_unit_code.setter
    def customs_unit_code(self, customs_unit_code):
        """Sets the customs_unit_code of this PackageItem.

        aka customsUnitCodeSKU. The quantity unit code of current sku for customs purpose. Both Chinese or number are ok.  # noqa: E501

        :param customs_unit_code: The customs_unit_code of this PackageItem.  # noqa: E501
        :type: str
        """

        self._customs_unit_code = customs_unit_code

    @property
    def customs_unit_code_package(self):
        """Gets the customs_unit_code_package of this PackageItem.  # noqa: E501

        The quantity unit code customs purpose. Declaration Unit, 申报单位.  # noqa: E501

        :return: The customs_unit_code_package of this PackageItem.  # noqa: E501
        :rtype: str
        """
        return self._customs_unit_code_package

    @customs_unit_code_package.setter
    def customs_unit_code_package(self, customs_unit_code_package):
        """Sets the customs_unit_code_package of this PackageItem.

        The quantity unit code customs purpose. Declaration Unit, 申报单位.  # noqa: E501

        :param customs_unit_code_package: The customs_unit_code_package of this PackageItem.  # noqa: E501
        :type: str
        """

        self._customs_unit_code_package = customs_unit_code_package

    @property
    def customs_unit_code_weight(self):
        """Gets the customs_unit_code_weight of this PackageItem.  # noqa: E501

        The weight unit code for customs purpose.  # noqa: E501

        :return: The customs_unit_code_weight of this PackageItem.  # noqa: E501
        :rtype: str
        """
        return self._customs_unit_code_weight

    @customs_unit_code_weight.setter
    def customs_unit_code_weight(self, customs_unit_code_weight):
        """Sets the customs_unit_code_weight of this PackageItem.

        The weight unit code for customs purpose.  # noqa: E501

        :param customs_unit_code_weight: The customs_unit_code_weight of this PackageItem.  # noqa: E501
        :type: str
        """

        self._customs_unit_code_weight = customs_unit_code_weight

    @property
    def customs_filing_id(self):
        """Gets the customs_filing_id of this PackageItem.  # noqa: E501

        The returned filing id of current SKU from customs  # noqa: E501

        :return: The customs_filing_id of this PackageItem.  # noqa: E501
        :rtype: str
        """
        return self._customs_filing_id

    @customs_filing_id.setter
    def customs_filing_id(self, customs_filing_id):
        """Sets the customs_filing_id of this PackageItem.

        The returned filing id of current SKU from customs  # noqa: E501

        :param customs_filing_id: The customs_filing_id of this PackageItem.  # noqa: E501
        :type: str
        """

        self._customs_filing_id = customs_filing_id

    @property
    def spec(self):
        """Gets the spec of this PackageItem.  # noqa: E501

        The spec of current product.  # noqa: E501

        :return: The spec of this PackageItem.  # noqa: E501
        :rtype: str
        """
        return self._spec

    @spec.setter
    def spec(self, spec):
        """Sets the spec of this PackageItem.

        The spec of current product.  # noqa: E501

        :param spec: The spec of this PackageItem.  # noqa: E501
        :type: str
        """

        self._spec = spec

    @property
    def model(self):
        """Gets the model of this PackageItem.  # noqa: E501

        The model of current product.  # noqa: E501

        :return: The model of this PackageItem.  # noqa: E501
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this PackageItem.

        The model of current product.  # noqa: E501

        :param model: The model of this PackageItem.  # noqa: E501
        :type: str
        """

        self._model = model

    @property
    def ingredients(self):
        """Gets the ingredients of this PackageItem.  # noqa: E501

        The ingredients of current product.  # noqa: E501

        :return: The ingredients of this PackageItem.  # noqa: E501
        :rtype: str
        """
        return self._ingredients

    @ingredients.setter
    def ingredients(self, ingredients):
        """Sets the ingredients of this PackageItem.

        The ingredients of current product.  # noqa: E501

        :param ingredients: The ingredients of this PackageItem.  # noqa: E501
        :type: str
        """

        self._ingredients = ingredients

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PackageItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PackageItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "nomad-pilot-cli"
VERSION = "1.29.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Nomad Pilot",
    author="OpenAPI Generator community",
    author_email="paul@samarkand.global",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Nomad Pilot"],
    install_requires=REQUIRES + ["querystring==0.1.0"],
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing.

    Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf-
    express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_.

    Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_
    and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_.

    - Install for node with ``npm install nomad_pilot_cli``
    - Install for python with ``pip install nomad-pilot-cli``
    """
)



# coding: utf-8

"""
    Nomad Pilot

    This is the API descriptor for the Nomad Pilot API, responsible for shipping and logistics processing. Developed by `Samarkand Global <https://samarkand.global>`_ in partnership with `SF Express <https://www.sf- express.com/cn/sc/>`_, `eSinotrans <http://www.esinotrans.com/haitao.html>`_. Read the documentation online at `Nomad API Suite <https://api.samarkand.io/>`_ and Check out the detailed `changelog <https://gitlab.com/samarkand-nomad/nomad_readme/-/raw/master/history/nomad_pilot.md>`_. - Install for node with ``npm install nomad_pilot_cli`` - Install for python with ``pip install nomad-pilot-cli``  # noqa: E501

    The version of the OpenAPI document: 1.29.1
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import nomad_pilot_cli
from nomad_pilot_cli.models.api_response_data import ApiResponseData  # noqa: E501
from nomad_pilot_cli.rest import ApiException

class TestApiResponseData(unittest.TestCase):
    """ApiResponseData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ApiResponseData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = nomad_pilot_cli.models.api_response_data.ApiResponseData()  # noqa: E501
        if include_optional :
            return ApiResponseData(
                waybill_id = '0', 
                order_sn = '0', 
                order_ref = '0', 
                seller_order_ref = '0', 
                domestic_delivery_company = 'YTO', 
                delivery_status = '0', 
                delivery_note = '0', 
                delivery_slip_url = '0', 
                tracking_url = '0', 
                check_points = ["@accept_time 2020-05-01 04:59:38; @accept_address 伦敦; @remark 寄方准备快件中,当前地点: 【GB London Delivery Centre (英國倫敦收派中心)】; @opcode 647; @zoneGmt 1","...","@accept_time 2020-05-13 09:10:49; @accept_address 江门市;  @remark 在官网'运单资料&签收图',可查看签收人信息; @opcode 8000; @stayWhyCode  1; @zoneGmt 8"]
            )
        else :
            return ApiResponseData(
        )

    def testApiResponseData(self):
        """Test ApiResponseData"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
